import typer
from rich.console import Console
from rich.table import Table
from .model import Todo
from .database import get_all_todos, delete_todo, insert_todo, complete_todo, update_todo, clear
from datetime import datetime

console = Console()

app = typer.Typer()


@app.command(short_help="add an item from to-do list")
def add(task: str, category: str):
    typer.echo(f"adding {task}, {category}")
    todo = Todo(task, category)
    insert_todo(todo)
    show()


@app.command(short_help="delete an item at specified position from to-do list")
def delete(position: int):
    typer.echo(f"deleting {position}")
    # indices in UI begin at 1, but in database at 0
    delete_todo(position-1)
    show()


@app.command(short_help="update status or description of an item at specified position")
def update(position: int, task: str = None, category: str = None):
    typer.echo(f"updating {position}")
    update_todo(position-1, task, category)
    show()


@app.command(short_help="complete an item at specified position")
def complete(position: int):
    typer.echo(f"complete {position}")
    complete_todo(position-1)
    show()


@app.command(short_help="show list of all tasks for current day")
def show():
    tasks = get_all_todos()
    console.print(f"[bold magenta]Todos on {datetime.today().strftime('%Y-%m-%d')}[/bold magenta]!")
    console.print("[bold green]Remember to finish all tasks for the end of the day. Good luck![/bold green]")

    table = Table(show_header=True, header_style="bold blue")
    table.add_column("#", style="dim", width=6)
    table.add_column("Todo", min_width=20)
    table.add_column("Category", min_width=12, justify="right")
    table.add_column("Done", min_width=12, justify="right")

    def get_category_color(category):
        COLORS = {'Work': 'cyan', 'Sports': 'blue', 'Study': 'yellow', 'Home': 'white', 'Done': 'green'}
        if category in COLORS:
            return COLORS[category]
        return 'white'

    for idx, task in enumerate(tasks, start=1):
        c = get_category_color(task.category)
        is_done_str = "Done" if task.status == 2 else "In progress..."
        cc = get_category_color(is_done_str)
        table.add_row(str(idx), task.task, f"[{c}]{task.category}[/{c}]", f"[{cc}]{is_done_str}[/{cc}]")
    console.print(table)


@app.command(name="clear", short_help="delete all items from list")
def clear_screen(
    force: bool = typer.Option(
        ...,
        prompt="Delete all to-dos?",
        help="Force deletion without confirmation.",
    )):
    if force:
        clear()
        typer.secho("Delete all todoes and clear the screen", fg=typer.colors.RED)
        show()
    else:
        typer.echo("Operation canceled")




import pathlib
from setuptools import setup, find_packages
import sys

# The directory containing this file
HERE = pathlib.Path(__file__).parent

# The text of the README file
README = (HERE / "README.md").read_text()

# This call to setup() does all the work
setup(
    name="cli-todoer",
    version="1.0.8",
    description="An easy command line interface for saving tasks to to-do list for current day",
    long_description=README,
    long_description_content_type="text/markdown",
    url="https://github.com/VladaZakharova/CLI-todoer",
    author="Vlada Zakharova",
    author_email="vladazaharova0@gmail.com",
    license='MIT',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License',
        "Programming Language :: Python :: 3.7",
    ],
    packages=find_packages(exclude=("venv", ".git",)),
    include_package_data=True,
    install_requires=[
        "typer==0.4.0",
        "rich==11.0.0",
        "click==8.0.3",
        "commonmark==0.9.1",
        "typing-extensions==4.1.1"
    ] + (["colorama==0.4.4"] if "win" in sys.platform else []),
    entry_points={
        "console_scripts": [
            "todoer=todoer.__main__:main",
        ]
    },
)